==> tine20-voip_2019.12.5.tar.bz2: Phone/js/Phone-lang-sq-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Phone **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Phone'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Albanian (http://www.transifex.com/tine20/tine20/language/sq/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: sq\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Call"
: "Thirrje"

, "Calls"
: "Thirrje"

, "Line"
: "Linja"

, "Caller Id"
: "ID e thirrësit"

, "Start"
: "Fillo"

, "Connected"
: "Lidhur"

, "Disconnected"
: "Çlidhur"

, "Duration"
: "Kohëzgjatja"

, "Ringing"
: "Duke tringëlluar"

, "Direction"
: "Drejtim"

, "Source"
: "Burim"

, "Destination"
: "Destinacioni"

, "Phone"
: ""

, "Phones"
: "Telefonë"

, "Settings"
: "KOnfigurime"

, "Lines"
: "Linja"

, "Description"
: "Përshkrimi"

, "Number"
: "Numër"

, "Cancel"
: "Anullo"

, "Dial"
: "Formo numrin"

, "Error"
: "Gabim"

, "Not possible to dial."
: "E pa mjundur të formohet numri"

, "Edit phone settings"
: "Modifiko konfigurimet e telefonit"

, "Dial number"
: "Thirr Numrin"

, "Initiate a new outgoing call"
: "Nis një thirrje dalëse"

, "No phone selected"
: "Nuk është zgjedhur asnjë telefon"

, "Please select the desired phone in the tree!"
: "Ju lutem zgjidhni telefonin e kërkuar në \"pemë\"!"

, "Call contact"
: "Thërrit Kontantin"

, "Work"
: "Punë"

, "Home"
: "Shtëpi"

, "Cell"
: "Celular"

, "Cell private"
: "Celular Privat"

, "Incoming call"
: "Thirrje Hyrëse"

, "Outgoing call"
: "Thirrje dalëse"

, "unknown number"
: "Numër i panjohur"

, "local prefix for outgoing calls"
: ""

, "telephone area code"
: ""

, "regex for local calls"
: ""

, "identifies if a calling number is a local call without leading area code"
: ""

, "own telephone number"
: ""

, "own telephone number to prefix to internal calls"
: ""

, "Calls this week"
: "Thirrje kësaj jave"

, "Incoming and outgoing calls of this week"
: "Thirrje hyrjëse dhe dalëse të kësaj jave"

, "Calls last week"
: "Thirrje javës së shkuar"

, "Incoming and outgoing calls of last week"
: "Thirrje hyrëse dhe dalëse të javës së shkuar"

, "Calls this month"
: "Thirrje këtë muaj"

, "Incoming and outgoing calls of this month"
: "Thirrje hyrëse dhe dalëse të këtij muaji"

, "Calls last month"
: "Thirrje muajit të shkuar"

, "Incoming and outgoing calls of last month"
: "Thirrje hyrëse dhe dalëse të muajit të kaluar"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-voip_2020.03.4.tar.bz2: Phone/js/Phone-lang-sq-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Phone **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Phone'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Albanian (http://www.transifex.com/tine20/tine20/language/sq/)\nLanguage: sq\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Incoming call"
: "Thirrje Hyrëse"

, "Outgoing call"
: "Thirrje dalëse"

, "unknown number"
: "Numër i panjohur"

, "Phone"
: ""

, "Line"
: "Linja"

, "Number"
: "Numër"

, "Cancel"
: "Anullo"

, "Dial"
: "Formo numrin"

, "Error"
: "Gabim"

, "Not possible to dial."
: "E pa mjundur të formohet numri"

, "Call contact"
: "Thërrit Kontantin"

, "Work"
: "Punë"

, "Home"
: "Shtëpi"

, "Cell"
: "Celular"

, "Cell private"
: "Celular Privat"

, "Edit phone settings"
: "Modifiko konfigurimet e telefonit"

, "Dial number"
: "Thirr Numrin"

, "Initiate a new outgoing call"
: "Nis një thirrje dalëse"

, "Phones"
: "Telefonë"

, "No phone selected"
: "Nuk është zgjedhur asnjë telefon"

, "Please select the desired phone in the tree!"
: "Ju lutem zgjidhni telefonin e kërkuar në \"pemë\"!"

, "Calls this week"
: "Thirrje kësaj jave"

, "Calls last week"
: "Thirrje javës së shkuar"

, "Calls this month"
: "Thirrje këtë muaj"

, "Calls last month"
: "Thirrje muajit të shkuar"

, "Incoming and outgoing calls of this week"
: "Thirrje hyrjëse dhe dalëse të kësaj jave"

, "Incoming and outgoing calls of last week"
: "Thirrje hyrëse dhe dalëse të javës së shkuar"

, "Incoming and outgoing calls of this month"
: "Thirrje hyrëse dhe dalëse të këtij muaji"

, "Incoming and outgoing calls of last month"
: "Thirrje hyrëse dhe dalëse të muajit të kaluar"

, "Local prefix for outgoing calls"
: ""

, "telephone area code"
: ""

, "regex for local calls"
: ""

, "Identifies if a calling number is a local call without leading area code."
: ""

, "own telephone number"
: ""

, "Own telephone number to prefix to internal calls."
: ""

, "Call"
: "Thirrje"

, "Calls"
: "Thirrje"

, "Caller Id"
: "ID e thirrësit"

, "Start"
: "Fillo"

, "Connected"
: "Lidhur"

, "Disconnected"
: "Çlidhur"

, "Duration"
: "Kohëzgjatja"

, "Ringing"
: "Duke tringëlluar"

, "Direction"
: "Drejtim"

, "Source"
: "Burim"

, "Destination"
: "Destinacioni"

, "resolved destination"
: ""

, "Settings"
: "KOnfigurime"

, "Lines"
: "Linja"

, "Description"
: "Përshkrimi"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
